Ultimate analysis bases
=======================

Ultimate analysis provides the percentage composition of a material in terms of carbon (C), hydrogen (H), oxygen (O), nitrogen (N), sulfur (S), ash, and moisture. It can be represented on an as-determined basis (ad), as-received basis (ar), dry basis (dry), and dry-ash free basis (daf).

Source code
-----------

.. autoclass:: chemics.Ultimate
   :members:
